summaryrefslogtreecommitdiffstats
path: root/extensions/common/permissions/permissions_data.cc
diff options
context:
space:
mode:
Diffstat (limited to 'extensions/common/permissions/permissions_data.cc')
-rw-r--r--extensions/common/permissions/permissions_data.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/extensions/common/permissions/permissions_data.cc b/extensions/common/permissions/permissions_data.cc
index 85000a2..8fde199 100644
--- a/extensions/common/permissions/permissions_data.cc
+++ b/extensions/common/permissions/permissions_data.cc
@@ -584,12 +584,13 @@ bool PermissionsData::RequiresActionForScriptExecution(
int tab_id,
const GURL& url) {
// For now, the user should be notified when an extension with all hosts
// permission tries to execute a script on a page, with exceptions for policy-
// enabled and component extensions. If this doesn't meet those criteria,
// return immediately.
if (!extension->ShouldDisplayInExtensionSettings() ||
Manifest::IsPolicyLocation(extension->location()) ||
Manifest::IsComponentLocation(extension->location()) ||
+ CanExecuteScriptEverywhere(extension) ||
!ShouldWarnAllHosts(extension)) {
return false;
}
@@ -584,12 +584,13 @@ bool PermissionsData::RequiresActionForScriptExecution(
const GURL& url) {
// For now, the user should be notified when an extension with all hosts
- // permission tries to execute a script on a page, with exceptions for policy-
- // enabled and component extensions. If this doesn't meet those criteria,
- // return immediately.
+ // permission tries to execute a script on a page. Exceptions for policy-
+ // enabled and component extensions, and extensions which are whitelisted to
+ // execute scripts everywhere.
if (!extension->ShouldDisplayInExtensionSettings() ||
Manifest::IsPolicyLocation(extension->location()) ||